@@ -1,5 +1,5 @@
 package Bitcoin::Crypto::Script;
-$Bitcoin::Crypto::Script::VERSION = '2.001';
+$Bitcoin::Crypto::Script::VERSION = '2.002';
 use v5.10;
 use strict;
 use warnings;
@@ -15,7 +15,7 @@ use Bitcoin::Crypto::Constants;
 use Bitcoin::Crypto::Base58 qw(encode_base58check decode_base58check);
 use Bitcoin::Crypto::Bech32 qw(encode_segwit decode_segwit get_hrp);
 use Bitcoin::Crypto::Constants;
-use Bitcoin::Crypto::Util qw(hash160 hash256);
+use Bitcoin::Crypto::Util qw(hash160 hash256 get_address_type);
 use Bitcoin::Crypto::Exception;
 use Bitcoin::Crypto::Types qw(Maybe ArrayRef HashRef Str Object ByteStr Any ScriptType ScriptDesc);
 use Bitcoin::Crypto::Script::Opcode;
@@ -70,9 +70,13 @@ sub _build
 			my $decoded = decode_base58check($address);
 			my $network_byte = substr $decoded, 0, 1, '';
 
+			Bitcoin::Crypto::Exception::Address->raise(
+				"legacy scripts should contain 20 bytes"
+			) unless length $decoded == 20;
+
 			my $byte_method = lc "p2${type}_byte";
 			Bitcoin::Crypto::Exception::NetworkCheck->raise(
-				"provided address $address does not belong to network " . $self->network->name
+				"provided address $address is not P2$type on network " . $self->network->name
 			) if $network_byte ne $self->network->$byte_method;
 
 			Bitcoin::Crypto::Script::Common->fill($type => $self, $decoded);
@@ -527,6 +531,10 @@ sub from_standard
 {
 	my ($class, $desc) = @_;
 
+	if ($desc->[0] eq 'address') {
+		$desc->[0] = get_address_type($desc->[1]);
+	}
+
 	return $class->new(
 		type => $desc->[0],
 		address => $desc->[1],
@@ -806,9 +814,16 @@ Creates a new script instance from a bytestring.
 =head2 from_standard
 
 	$object = Bitcoin::Crypto::Script->from_standard([P2PKH => '1Ehr6cNDzPCx3wQRu1sMdXWViEi2MQnFzH'])
+	$object = Bitcoin::Crypto::Script->from_standard([address => '1Ehr6cNDzPCx3wQRu1sMdXWViEi2MQnFzH'])
 
-Creates a new object of standard type with given address. The address must
-match the network specified for the script (see L</set_network>).
+Creates a new object of standard type with given address. The address must be
+of the currently default network. In case of C<NULLDATA>, C<P2MS> and C<P2PK>
+there is no address, and the second argument must be custom data (C<NULLDATA>),
+public key (C<P2PK>) or an array reference with number N of signatures followed
+by M public keys (N of M C<P2MS>).
+
+The first argument can also be specified as C<address> to enable auto-detection
+of script type.
 
 =head2 get_hash
 
